/* $Id: resource.h 37987 2011-07-18 08:11:16Z vboxsync $ */
/** @file
 * VBoxStub - resource header file.
 */

/*
 * Copyright (C) 2009 Oracle Corporation
 *
 * This file is part of VirtualBox Open Source Edition (OSE), as
 * available from http://www.virtualbox.org. This file is free software;
 * you can redistribute it and/or modify it under the terms of the GNU
 * General Public License (GPL) as published by the Free Software
 * Foundation, in version 2 as it comes in the "COPYING" file of the
 * VirtualBox OSE distribution. VirtualBox OSE is distributed in the
 * hope that it will be useful, but WITHOUT ANY WARRANTY of any kind.
 */
#define IDI_VIRTUALBOX 101

#define RT_MANIFEST 24
#define APP_MANIFEST 1

